@@ -1,5 +1,6 @@
 //! It contains some child modules that do not belongs to any other parent modules.
 
+pub mod camel_case_str;
 pub mod delayed;
 pub mod dynamic;
 pub mod hash;
@@ -11,7 +12,10 @@ pub mod reactive;
 pub mod reactivity_manager;
 pub mod readonly;
 pub mod sec;
+pub mod snake_case_str;
+pub mod to_words;
 
+pub use camel_case_str::CamelCaseStr;
 pub use delayed::Delayed;
 pub use dynamic::Dynamic;
 pub use hash::Hash;
@@ -23,3 +27,5 @@ pub use reactive::Reactive;
 pub use reactivity_manager::ReactivityManager;
 pub use readonly::Readonly;
 pub use sec::Sec;
+pub use snake_case_str::SnakeCaseStr;
+pub use to_words::ToWords;
